@@ -1,21 +1,7 @@
-/*
- * Copyright (C) 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     houchengqiu <houchengqiu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2021 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "grandsearchlistdelegate.h"
 #include "grandsearchlistview.h"
 #include "global/builtinsearch.h"
@@ -42,6 +28,7 @@
 #define TailMaxWidth              150      // 拖尾信息最大显示宽度
 
 DWIDGET_USE_NAMESPACE
+using namespace GrandSearch;
 
 GrandSearchListDelegate::GrandSearchListDelegate(QAbstractItemView *parent)
     : DStyledItemDelegate(parent)
@@ -134,7 +121,15 @@ void GrandSearchListDelegate::drawSelectState(QPainter *painter, const QStyleOpt
     if (option.state & QStyle::State_MouseOver) {
         painter->save();
         painter->setPen(Qt::NoPen);
-        QColor hovertColor(0, 0, 0, int(255*0.05));
+
+        QColor hovertColor;
+        const GrandSearchListView *listview = qobject_cast<const GrandSearchListView *>(option.widget);
+        if ((listview->getThemeType() == DGuiApplicationHelper::DarkType)
+                || (index.isValid() && index == listview->currentIndex())) {
+            hovertColor = QColor(255, 255, 255, static_cast<int>(255 * 0.05));
+        } else {
+            hovertColor = QColor(0, 0, 0, static_cast<int>(255*0.05));
+        }
         painter->setBrush(hovertColor);
         QRect selecteColorRect = option.rect.adjusted(0, 0, 0, 0);
         painter->drawRoundedRect(selecteColorRect, 8, 8);
@@ -157,6 +152,7 @@ void GrandSearchListDelegate::drawSearchResultText(QPainter *painter, const QSty
 
     // 设置字体
     QFont nameFont = DFontSizeManager::instance()->get(DFontSizeManager::T6);
+    nameFont.setWeight(QFont::Medium);
 
     const QString &name = index.data(DATA_ROLE).value<MatchedItem>().name;
     const QString &searcher = index.data(DATA_ROLE).value<MatchedItem>().searcher;
