@@ -1,21 +1,7 @@
-/*
- * Copyright (C) 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     houchengqiu <houchengqiu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2021 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "grandsearchlistview.h"
 #include "grandsearchlistmodel.h"
 #include "grandsearchlistdelegate.h"
@@ -23,6 +9,7 @@
 #include "global/matcheditem.h"
 #include "global/builtinsearch.h"
 #include "global/accessibility/acintelfunctions.h"
+#include "gui/exhibition/matchresult/groupwidget.h"
 
 #include <DGuiApplicationHelper>
 #include <DStandardPaths>
@@ -31,9 +18,11 @@
 #include <QFileInfo>
 #include <QPainter>
 #include <QMouseEvent>
+#include <QVariant>
 
-DCORE_USE_NAMESPACE
 using namespace GrandSearch;
+DCORE_USE_NAMESPACE
+DWIDGET_USE_NAMESPACE
 
 #define ICON_SIZE 24
 #define ListItemTextMaxWidth      240      // 文本元素最大显示宽度
