@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     wangchunlin<wangchunlin@uniontech.com>
- *
- * Maintainer: wangchunlin<wangchunlin@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2021 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #ifndef IMAGEVIEW_H
 #define IMAGEVIEW_H
 
@@ -31,6 +15,9 @@ DWIDGET_BEGIN_NAMESPACE
 class DLabel;
 DWIDGET_END_NAMESPACE
 
+namespace GrandSearch {
+namespace image_preview {
+
 class ImageView : public Dtk::Widget::DWidget
 {
     Q_OBJECT
@@ -53,7 +40,6 @@ private:
 private slots:
     void onMovieFrameChanged(int frameNumber);
     void showErrorPage();
-
 private:
     QVBoxLayout *m_mainLayout = nullptr;
 
@@ -68,4 +54,6 @@ private:
     Dtk::Widget::DLabel *m_titleLabel;  // 显示名称
 };
 
+}}
+
 #endif // IMAGEVIEW_H
